<!--
A new scriv changelog fragment.

Uncomment the section that is right (remove the HTML comment wrapper).
For top level release notes, leave all the headers commented out.
-->

<!--
### Removed

- A bullet item for the Removed category.

-->
### Added

- created possibility with batch algorithm testing with kubernetes docker desktop kubeadm administrator kernel
- done k8s for the kubernetes with local server

### Changed

- made another file for the kubernetes suite with experiment possibility
- changed docker file
- moved md files to the separated directory
<!--
### Deprecated

- A bullet item for the Deprecated category.

-->
<!--
### Fixed

- A bullet item for the Fixed category.

-->
<!--
### Security

- A bullet item for the Security category.

-->
